@@ -17,7 +17,7 @@ from typing import Any, Dict, List, Type, overload
 
 from botocore.client import ClientMeta
 
-from mypy_boto3_networkmanager.paginator import (
+from .paginator import (
     DescribeGlobalNetworksPaginator,
     GetConnectionsPaginator,
     GetCustomerGatewayAssociationsPaginator,
@@ -28,7 +28,6 @@ from mypy_boto3_networkmanager.paginator import (
     GetTransitGatewayConnectPeerAssociationsPaginator,
     GetTransitGatewayRegistrationsPaginator,
 )
-
 from .type_defs import (
     AssociateCustomerGatewayResponseTypeDef,
     AssociateLinkResponseTypeDef,
@@ -99,7 +98,7 @@ class Exceptions:
 
 class NetworkManagerClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client)
     [Show boto3-stubs documentation](./client.md)
     """
 
@@ -110,16 +109,16 @@ class NetworkManagerClient:
         self, CustomerGatewayArn: str, GlobalNetworkId: str, DeviceId: str, LinkId: str = None
     ) -> AssociateCustomerGatewayResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.associate_customer_gateway)
-        [Show boto3-stubs documentation](./client.md#associate-customer-gateway)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.associate_customer_gateway)
+        [Show boto3-stubs documentation](./client.md#associate_customer_gateway)
         """
 
     def associate_link(
         self, GlobalNetworkId: str, DeviceId: str, LinkId: str
     ) -> AssociateLinkResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.associate_link)
-        [Show boto3-stubs documentation](./client.md#associate-link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.associate_link)
+        [Show boto3-stubs documentation](./client.md#associate_link)
         """
 
     def associate_transit_gateway_connect_peer(
@@ -130,14 +129,14 @@ class NetworkManagerClient:
         LinkId: str = None,
     ) -> AssociateTransitGatewayConnectPeerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.associate_transit_gateway_connect_peer)
-        [Show boto3-stubs documentation](./client.md#associate-transit-gateway-connect-peer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.associate_transit_gateway_connect_peer)
+        [Show boto3-stubs documentation](./client.md#associate_transit_gateway_connect_peer)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.can_paginate)
-        [Show boto3-stubs documentation](./client.md#can-paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.can_paginate)
+        [Show boto3-stubs documentation](./client.md#can_paginate)
         """
 
     def create_connection(
@@ -151,8 +150,8 @@ class NetworkManagerClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateConnectionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.create_connection)
-        [Show boto3-stubs documentation](./client.md#create-connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.create_connection)
+        [Show boto3-stubs documentation](./client.md#create_connection)
         """
 
     def create_device(
@@ -169,16 +168,16 @@ class NetworkManagerClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateDeviceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.create_device)
-        [Show boto3-stubs documentation](./client.md#create-device)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.create_device)
+        [Show boto3-stubs documentation](./client.md#create_device)
         """
 
     def create_global_network(
         self, Description: str = None, Tags: List["TagTypeDef"] = None
     ) -> CreateGlobalNetworkResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.create_global_network)
-        [Show boto3-stubs documentation](./client.md#create-global-network)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.create_global_network)
+        [Show boto3-stubs documentation](./client.md#create_global_network)
         """
 
     def create_link(
@@ -192,8 +191,8 @@ class NetworkManagerClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateLinkResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.create_link)
-        [Show boto3-stubs documentation](./client.md#create-link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.create_link)
+        [Show boto3-stubs documentation](./client.md#create_link)
         """
 
     def create_site(
@@ -204,80 +203,80 @@ class NetworkManagerClient:
         Tags: List["TagTypeDef"] = None,
     ) -> CreateSiteResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.create_site)
-        [Show boto3-stubs documentation](./client.md#create-site)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.create_site)
+        [Show boto3-stubs documentation](./client.md#create_site)
         """
 
     def delete_connection(
         self, GlobalNetworkId: str, ConnectionId: str
     ) -> DeleteConnectionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.delete_connection)
-        [Show boto3-stubs documentation](./client.md#delete-connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.delete_connection)
+        [Show boto3-stubs documentation](./client.md#delete_connection)
         """
 
     def delete_device(self, GlobalNetworkId: str, DeviceId: str) -> DeleteDeviceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.delete_device)
-        [Show boto3-stubs documentation](./client.md#delete-device)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.delete_device)
+        [Show boto3-stubs documentation](./client.md#delete_device)
         """
 
     def delete_global_network(self, GlobalNetworkId: str) -> DeleteGlobalNetworkResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.delete_global_network)
-        [Show boto3-stubs documentation](./client.md#delete-global-network)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.delete_global_network)
+        [Show boto3-stubs documentation](./client.md#delete_global_network)
         """
 
     def delete_link(self, GlobalNetworkId: str, LinkId: str) -> DeleteLinkResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.delete_link)
-        [Show boto3-stubs documentation](./client.md#delete-link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.delete_link)
+        [Show boto3-stubs documentation](./client.md#delete_link)
         """
 
     def delete_site(self, GlobalNetworkId: str, SiteId: str) -> DeleteSiteResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.delete_site)
-        [Show boto3-stubs documentation](./client.md#delete-site)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.delete_site)
+        [Show boto3-stubs documentation](./client.md#delete_site)
         """
 
     def deregister_transit_gateway(
         self, GlobalNetworkId: str, TransitGatewayArn: str
     ) -> DeregisterTransitGatewayResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.deregister_transit_gateway)
-        [Show boto3-stubs documentation](./client.md#deregister-transit-gateway)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.deregister_transit_gateway)
+        [Show boto3-stubs documentation](./client.md#deregister_transit_gateway)
         """
 
     def describe_global_networks(
         self, GlobalNetworkIds: List[str] = None, MaxResults: int = None, NextToken: str = None
     ) -> DescribeGlobalNetworksResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.describe_global_networks)
-        [Show boto3-stubs documentation](./client.md#describe-global-networks)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.describe_global_networks)
+        [Show boto3-stubs documentation](./client.md#describe_global_networks)
         """
 
     def disassociate_customer_gateway(
         self, GlobalNetworkId: str, CustomerGatewayArn: str
     ) -> DisassociateCustomerGatewayResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.disassociate_customer_gateway)
-        [Show boto3-stubs documentation](./client.md#disassociate-customer-gateway)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.disassociate_customer_gateway)
+        [Show boto3-stubs documentation](./client.md#disassociate_customer_gateway)
         """
 
     def disassociate_link(
         self, GlobalNetworkId: str, DeviceId: str, LinkId: str
     ) -> DisassociateLinkResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.disassociate_link)
-        [Show boto3-stubs documentation](./client.md#disassociate-link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.disassociate_link)
+        [Show boto3-stubs documentation](./client.md#disassociate_link)
         """
 
     def disassociate_transit_gateway_connect_peer(
         self, GlobalNetworkId: str, TransitGatewayConnectPeerArn: str
     ) -> DisassociateTransitGatewayConnectPeerResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.disassociate_transit_gateway_connect_peer)
-        [Show boto3-stubs documentation](./client.md#disassociate-transit-gateway-connect-peer)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.disassociate_transit_gateway_connect_peer)
+        [Show boto3-stubs documentation](./client.md#disassociate_transit_gateway_connect_peer)
         """
 
     def generate_presigned_url(
@@ -288,8 +287,8 @@ class NetworkManagerClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](./client.md#generate-presigned-url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.generate_presigned_url)
+        [Show boto3-stubs documentation](./client.md#generate_presigned_url)
         """
 
     def get_connections(
@@ -301,8 +300,8 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetConnectionsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.get_connections)
-        [Show boto3-stubs documentation](./client.md#get-connections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.get_connections)
+        [Show boto3-stubs documentation](./client.md#get_connections)
         """
 
     def get_customer_gateway_associations(
@@ -313,8 +312,8 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetCustomerGatewayAssociationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.get_customer_gateway_associations)
-        [Show boto3-stubs documentation](./client.md#get-customer-gateway-associations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.get_customer_gateway_associations)
+        [Show boto3-stubs documentation](./client.md#get_customer_gateway_associations)
         """
 
     def get_devices(
@@ -326,8 +325,8 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetDevicesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.get_devices)
-        [Show boto3-stubs documentation](./client.md#get-devices)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.get_devices)
+        [Show boto3-stubs documentation](./client.md#get_devices)
         """
 
     def get_link_associations(
@@ -339,8 +338,8 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetLinkAssociationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.get_link_associations)
-        [Show boto3-stubs documentation](./client.md#get-link-associations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.get_link_associations)
+        [Show boto3-stubs documentation](./client.md#get_link_associations)
         """
 
     def get_links(
@@ -354,8 +353,8 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetLinksResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.get_links)
-        [Show boto3-stubs documentation](./client.md#get-links)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.get_links)
+        [Show boto3-stubs documentation](./client.md#get_links)
         """
 
     def get_sites(
@@ -366,8 +365,8 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetSitesResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.get_sites)
-        [Show boto3-stubs documentation](./client.md#get-sites)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.get_sites)
+        [Show boto3-stubs documentation](./client.md#get_sites)
         """
 
     def get_transit_gateway_connect_peer_associations(
@@ -378,8 +377,8 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetTransitGatewayConnectPeerAssociationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_connect_peer_associations)
-        [Show boto3-stubs documentation](./client.md#get-transit-gateway-connect-peer-associations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_connect_peer_associations)
+        [Show boto3-stubs documentation](./client.md#get_transit_gateway_connect_peer_associations)
         """
 
     def get_transit_gateway_registrations(
@@ -390,34 +389,34 @@ class NetworkManagerClient:
         NextToken: str = None,
     ) -> GetTransitGatewayRegistrationsResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_registrations)
-        [Show boto3-stubs documentation](./client.md#get-transit-gateway-registrations)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.get_transit_gateway_registrations)
+        [Show boto3-stubs documentation](./client.md#get_transit_gateway_registrations)
         """
 
     def list_tags_for_resource(self, ResourceArn: str) -> ListTagsForResourceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.list_tags_for_resource)
-        [Show boto3-stubs documentation](./client.md#list-tags-for-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.list_tags_for_resource)
+        [Show boto3-stubs documentation](./client.md#list_tags_for_resource)
         """
 
     def register_transit_gateway(
         self, GlobalNetworkId: str, TransitGatewayArn: str
     ) -> RegisterTransitGatewayResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.register_transit_gateway)
-        [Show boto3-stubs documentation](./client.md#register-transit-gateway)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.register_transit_gateway)
+        [Show boto3-stubs documentation](./client.md#register_transit_gateway)
         """
 
     def tag_resource(self, ResourceArn: str, Tags: List["TagTypeDef"]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.tag_resource)
-        [Show boto3-stubs documentation](./client.md#tag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.tag_resource)
+        [Show boto3-stubs documentation](./client.md#tag_resource)
         """
 
     def untag_resource(self, ResourceArn: str, TagKeys: List[str]) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.untag_resource)
-        [Show boto3-stubs documentation](./client.md#untag-resource)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.untag_resource)
+        [Show boto3-stubs documentation](./client.md#untag_resource)
         """
 
     def update_connection(
@@ -429,8 +428,8 @@ class NetworkManagerClient:
         Description: str = None,
     ) -> UpdateConnectionResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.update_connection)
-        [Show boto3-stubs documentation](./client.md#update-connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.update_connection)
+        [Show boto3-stubs documentation](./client.md#update_connection)
         """
 
     def update_device(
@@ -447,16 +446,16 @@ class NetworkManagerClient:
         SiteId: str = None,
     ) -> UpdateDeviceResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.update_device)
-        [Show boto3-stubs documentation](./client.md#update-device)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.update_device)
+        [Show boto3-stubs documentation](./client.md#update_device)
         """
 
     def update_global_network(
         self, GlobalNetworkId: str, Description: str = None
     ) -> UpdateGlobalNetworkResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.update_global_network)
-        [Show boto3-stubs documentation](./client.md#update-global-network)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.update_global_network)
+        [Show boto3-stubs documentation](./client.md#update_global_network)
         """
 
     def update_link(
@@ -469,8 +468,8 @@ class NetworkManagerClient:
         Provider: str = None,
     ) -> UpdateLinkResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.update_link)
-        [Show boto3-stubs documentation](./client.md#update-link)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.update_link)
+        [Show boto3-stubs documentation](./client.md#update_link)
         """
 
     def update_site(
@@ -481,8 +480,8 @@ class NetworkManagerClient:
         Location: "LocationTypeDef" = None,
     ) -> UpdateSiteResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Client.update_site)
-        [Show boto3-stubs documentation](./client.md#update-site)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Client.update_site)
+        [Show boto3-stubs documentation](./client.md#update_site)
         """
 
     @overload
@@ -490,13 +489,13 @@ class NetworkManagerClient:
         self, operation_name: Literal["describe_global_networks"]
     ) -> DescribeGlobalNetworksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)[Show boto3-stubs documentation](./paginators.md#describeglobalnetworkspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Paginator.DescribeGlobalNetworks)[Show boto3-stubs documentation](./paginators.md#describeglobalnetworkspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_connections"]) -> GetConnectionsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections)[Show boto3-stubs documentation](./paginators.md#getconnectionspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Paginator.GetConnections)[Show boto3-stubs documentation](./paginators.md#getconnectionspaginator)
         """
 
     @overload
@@ -504,13 +503,13 @@ class NetworkManagerClient:
         self, operation_name: Literal["get_customer_gateway_associations"]
     ) -> GetCustomerGatewayAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)[Show boto3-stubs documentation](./paginators.md#getcustomergatewayassociationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Paginator.GetCustomerGatewayAssociations)[Show boto3-stubs documentation](./paginators.md#getcustomergatewayassociationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_devices"]) -> GetDevicesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)[Show boto3-stubs documentation](./paginators.md#getdevicespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Paginator.GetDevices)[Show boto3-stubs documentation](./paginators.md#getdevicespaginator)
         """
 
     @overload
@@ -518,19 +517,19 @@ class NetworkManagerClient:
         self, operation_name: Literal["get_link_associations"]
     ) -> GetLinkAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)[Show boto3-stubs documentation](./paginators.md#getlinkassociationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinkAssociations)[Show boto3-stubs documentation](./paginators.md#getlinkassociationspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_links"]) -> GetLinksPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)[Show boto3-stubs documentation](./paginators.md#getlinkspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Paginator.GetLinks)[Show boto3-stubs documentation](./paginators.md#getlinkspaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["get_sites"]) -> GetSitesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)[Show boto3-stubs documentation](./paginators.md#getsitespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Paginator.GetSites)[Show boto3-stubs documentation](./paginators.md#getsitespaginator)
         """
 
     @overload
@@ -538,7 +537,7 @@ class NetworkManagerClient:
         self, operation_name: Literal["get_transit_gateway_connect_peer_associations"]
     ) -> GetTransitGatewayConnectPeerAssociationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations)[Show boto3-stubs documentation](./paginators.md#gettransitgatewayconnectpeerassociationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayConnectPeerAssociations)[Show boto3-stubs documentation](./paginators.md#gettransitgatewayconnectpeerassociationspaginator)
         """
 
     @overload
@@ -546,5 +545,5 @@ class NetworkManagerClient:
         self, operation_name: Literal["get_transit_gateway_registrations"]
     ) -> GetTransitGatewayRegistrationsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.69/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)[Show boto3-stubs documentation](./paginators.md#gettransitgatewayregistrationspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.73/reference/services/networkmanager.html#NetworkManager.Paginator.GetTransitGatewayRegistrations)[Show boto3-stubs documentation](./paginators.md#gettransitgatewayregistrationspaginator)
         """
